# Copyright (c) 2014 Rackspace Hosting.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
# implied.
# See the License for the specific language governing permissions and
# limitations under the License.
from designateclient import exceptions as designateclient

from openstack_dashboard import exceptions

NOT_FOUND = exceptions.NOT_FOUND + (
    designateclient.ResourceNotFound,
    designateclient.NotFound,
    )
RECOVERABLE = exceptions.RECOVERABLE + (
    designateclient.BadRequest,
    designateclient.Conflict,
    )
UNAUTHORIZED = exceptions.UNAUTHORIZED + (
    designateclient.Forbidden,
    )
