{% extends 'base.html' %}
{% load i18n %}
{% block title %}{% trans 'Domain Records' %}{% endblock %}

{% block page_header %}
  {% include "horizon/common/_page_header.html" with title=_("Domain Records") %}
{% endblock page_header %}

{% block main %}
    <div class="sub-content grid-content">
        <div class="page_title table_header">
            <div>
                <h3>
                    <a href="{% url 'horizon:project:dns_domains:index' %}">{% trans "Domains" %}</a> : {{ domain.name }} &rarr;
                    {% trans "Records" %}
                </h3>
            </div>
            <div class="table_actions">
                <a href="{% url 'horizon:project:dns_domains:index' %}" class="close">&times;</a>
            </div>
        </div>
    <div class="nameservers_wrapper">
      <h3>{% trans "Nameservers" %}</h3>
      <ul>
      {% for server in servers %}
        <li>{{ server.name }}</li>
      {% endfor %}
      </ul>
    </div>

    {{ table.render }}
{% endblock %}
